R/construct_searches.R
construct_searches.Rd
Construct a named list to be used to identify matching file types based on their path names.
construct_searches(searches = NULL, keys = NULL)
Named list of regex queries.
Keys to subset the searches with by their names.
searches
Named list.
searches <- construct_searches()