Convert a BED file to any format supported by rtracklayer::export.
Paths to one or more BED files.
Genome build.
Which chromosomes to keep.
A character vector of one or more formats for export file to.
Path to save bigBed files.
Print messages.
Arguments passed on to rtracklayer::export.bw
conA path, URL or BigWigFile object. Connections are
not supported. For the functions ending in .bw, the file
format is indicated by the function name. For the export
and import methods, the format must be indicated another
way. If con is a path, or URL, either the file
extension or the format argument needs to be “bigWig”
or “bw”.
objectThe object to export, should be an RleList,
IntegerList, NumericList,
GRanges or something coercible to a GRanges.
Converted file paths.
if (FALSE) { # \dontrun{
files <- system.file("tests","test.bed",package = "rtracklayer")
out <- bed_to(files=files)
} # }