Call peaks from a bedGraph or bigWig file using SEACR (Sparse Enrichment Analysis for CUT&RUN).
Field 1: Target data bedgraph file in UCSC bedgraph format that omits regions containing 0 signal.
Control (IgG) data bedgraph file to generate an empirical
threshold for peak calling.
Alternatively, a numeric threshold n between 0 and 1 returns the top n
fraction of peaks based on total signal within peaks
(default: 0.05).
Field 3: "norm" (default: norm=TRUE)
denotes normalization of control
to target data, "non" (norm=FALSE) skips this behavior.
"norm" is recommended unless experimental and control data are already
rigorously normalized to each other (e.g. via spike-in).
Field 4:"relaxed" (stringent=FALSE)
uses a total signal
threshold between the knee and peak of the total signal curve,
and corresponds to the “relaxed” mode described in the text,
whereas “stringent” (default: stringent=TRUE)
uses the peak of the curve, and corresponds to “stringent” mode.
Directory to store cutoff_analysis
report and peak file in.
Name of the peak output file (stored in BED format).
Whether to return the path to the saved peak file, or the peak data itself as a GRanges object.
Remove temporary intermediate files generated by SEACR (i.e. )
When nThread>1, accelerates file importing
and peak calling using multi-core parallelisation.
Print messages.
GRanges or path to save peaks file.